Updating branch refs/heads/master
         to 693fc5ff3f337fb1e0fa40c8a5a126dfede6babd (commit)
       from ed8bfa93400d0d82a6c1f1ed417fe0a2edc8a125 (commit)

commit 693fc5ff3f337fb1e0fa40c8a5a126dfede6babd
Author: Jannis Pohlmann <[email protected]>
Date:   Sat Jan 9 21:46:52 2010 +0100

    Avoid compiler warning due to global name shadowing.

 tumbler/tumbler-provider-factory.c |    8 ++++----
 1 files changed, 4 insertions(+), 4 deletions(-)

diff --git a/tumbler/tumbler-provider-factory.c 
b/tumbler/tumbler-provider-factory.c
index 2adcffd..afa47e3 100644
--- a/tumbler/tumbler-provider-factory.c
+++ b/tumbler/tumbler-provider-factory.c
@@ -124,7 +124,7 @@ tumbler_provider_factory_add_types (TumblerProviderFactory 
*factory,
 {
   TumblerProviderInfo *provider_info;
   const GType         *types;
-  guint                index;
+  guint                idx;
   gint                 n_types;
   gint                 n;
 
@@ -142,11 +142,11 @@ tumbler_provider_factory_add_types 
(TumblerProviderFactory *factory,
       provider_info->type = types[n];
       provider_info->provider = NULL;
 
-      /* compute the index for this info */
-      index = factory->provider_infos->len - n_types + n;
+      /* compute the idx for this info */
+      idx = factory->provider_infos->len - n_types + n;
 
       /* insert the provider info into the array */
-      factory->provider_infos->pdata[index] = provider_info;
+      factory->provider_infos->pdata[idx] = provider_info;
     }
 }
 
_______________________________________________
Xfce4-commits mailing list
[email protected]
http://foo-projects.org/mailman/listinfo/xfce4-commits

Reply via email to